@@ -12,7 +12,7 @@ from chalk.utils.collections import ensure_tuple
 
 
 def build_inference_function(
-    model_version: ModelVersion, pkey: Feature, output_feature: Optional[Feature] = None
+    model_version: ModelVersion, pkey: Feature, output_feature: Optional[Feature] = None, text_model: bool = False
 ) -> Callable[[DataFrame], DataFrame]:
     """Build the core inference function that takes a DataFrame and returns predictions.
 
@@ -34,9 +34,22 @@ def build_inference_function(
         Function that takes a DataFrame and returns predictions
     """
     pkey_string = str(pkey)
+    if text_model:
+        # For text models, we expect a single column of string data
+        def fn(inp: DataFrame):
+            texts = inp[[c for c in inp.columns if c != pkey_string]].to_pyarrow().column(0).to_numpy()
+            result = model_version.predict(texts)
+            if output_feature is not None:
+                return inp[pkey_string].with_columns({output_feature: result})
+            return result
+
+        return fn
 
     def fn(inp: DataFrame):
-        result = model_version.predict(inp[[c for c in inp.columns if c != pkey_string]].to_pyarrow().__array__())
+        # Convert features to PyArrow table, excluding primary key
+        arr = inp[[c for c in inp.columns if c != pkey_string]].to_pyarrow().__array__()
+
+        result = model_version.predict(arr)
         if output_feature is not None:
             return inp[pkey_string].with_columns({output_feature: result})
         return result
@@ -60,7 +73,6 @@ def generate_inference_resolver(
 
         def resolver_factory():
             # Use the extracted build_inference_function
-            fn = build_inference_function(model_version, pkey, output_feature)
 
             cleaned_inputs = []
             for i in inputs:
@@ -69,6 +81,14 @@ def generate_inference_resolver(
                 except Exception as e:
                     raise ValueError(f"Could not find feature for input {i}: {e}")
 
+            try:
+                text_model = len(cleaned_inputs) == 1 and cleaned_inputs[0].typ.parsed_annotation is str
+            except Exception:
+                # Fallback in case of any issues determining the type
+                text_model = False
+
+            fn = build_inference_function(model_version, pkey, output_feature, text_model=text_model)
+
             identifier = model_version.identifier or ""
             model_reference = MODEL_REFERENCE_REGISTRY.get((model_version.name, identifier), None)
             if model_reference is not None:
