@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from chalk.ml.model_file_transfer import HFSourceConfig, LocalSourceConfig, S3SourceConfig, SourceConfig
+from chalk.ml.model_file_transfer import FileInfo, HFSourceConfig, LocalSourceConfig, S3SourceConfig, SourceConfig
 from chalk.ml.model_reference import ModelReference
 from chalk.ml.utils import ModelEncoding, ModelRunCriterion, ModelType
 
@@ -13,4 +13,5 @@ __all__ = (
     "S3SourceConfig",
     "HFSourceConfig",
     "ModelRunCriterion",
+    "FileInfo",
 )
