@@ -47,10 +47,14 @@ MODEL_HOOKS: Dict[Tuple[ModelType, ModelEncoding, Optional[str]], Callable[[str]
 
 
 def _to_numpy(X: Any):
-    """Convert input data to numpy array if it's a PyArrow table."""
+    """Convert input data to numpy array if it's a PyArrow table.
+
+    Note: In most cases, X is already a numpy array from inference.py.
+    This function exists for backward compatibility with other code paths.
+    """
     if hasattr(X, "to_pandas"):
-        # PyArrow table
-        return X.to_pandas().to_numpy()
+        # PyArrow object - convert directly to numpy (no pandas needed)
+        return X.__array__()
     return X
 
 
