@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from datetime import datetime
-from typing import Any, List
+from typing import Any
 
 from chalk.ml.model_hooks import MODEL_HOOKS, PREDICT_HOOKS
 from chalk.ml.utils import ModelEncoding, ModelType
@@ -62,7 +62,7 @@ class ModelVersion:
                     f"No load function defined for type {self.model_type} and extension {self.model_encoding}"
                 )
 
-    def predict(self, X: List[List[float]]):
+    def predict(self, X: Any):
         """Loads the model from the specified filename using the appropriate hook."""
 
         if self._predict_fn is None:
