@@ -111,7 +111,7 @@ class ParsedAnnotation:
             typ = self._features_cls.__annotations__[self._attribute_name]
         else:
             typ = self._parsed_annotation or self._underlying or self._unparsed_underlying
-        if sys.version_info >= (3, 9) and get_origin(typ) == typing.Annotated:
+        if get_origin(typ) == typing.Annotated:
             typ = typ.__origin__  # pyright: ignore
         if isinstance(typ, type):
             typ = typ.__name__
