@@ -530,6 +530,8 @@ class PostgreSQLSourceImpl(BaseSQLSource, TableIngestMixIn, SQLSourceWithTableIn
         for field in expected_output_schema:
             if field.name in arrow_table.column_names:
                 col = arrow_table.column(field.name)
+                if isinstance(col, pa.ChunkedArray):
+                    col = col.combine_chunks()
                 # Cast to expected type if needed
                 if col.type != field.type:
                     col = pc.cast(col, field.type)
