@@ -640,21 +640,28 @@ class AzureBlobStorageClient(StorageClient):
             raise missing_dependency_exception("chalkpy[runtime]")
         self.bucket = container_name  # interface requirement
         self._blob_service_client = blob_service_client
+        self._container_name = container_name
         self._container_client = blob_service_client.get_container_client(container_name)
         self._account_name = account_name
         self._executor = executor
         self.fs = adlfs.AzureBlobFileSystem(
             account_name=account_name,
+            credential=blob_service_client.credential,
         )
 
     @override
     def get_uri(self, filename: str) -> str:
         """Return a URI for a filename"""
-        return f"{self.protocol}://{self.bucket}@{self._account_name}.dfs.core.windows.net/{filename}"
+        return f"{self.protocol}://{self._container_name}@{self._account_name}.dfs.core.windows.net/{filename}"
 
     def get_https_uri(self, filename: str) -> str:
         """Return an HTTPS URI for signed URLs and direct access"""
-        return f"https://{self._account_name}.blob.core.windows.net/{self.bucket}/{filename}"
+        return f"https://{self._account_name}.blob.core.windows.net/{self._container_name}/{filename}"
+
+    def _normalize_path(self, path: str) -> str:
+        if path.startswith(self._container_name):
+            return path[len(self._container_name) + 1 :]
+        return path
 
     @override
     def upload_object(
@@ -688,7 +695,7 @@ class AzureBlobStorageClient(StorageClient):
             tags=[f"bucket:{self.bucket}", f"protocol:{self.protocol}"],
         )
 
-        blob_client = self._container_client.get_blob_client(filename)
+        blob_client = self._container_client.get_blob_client(self._normalize_path(filename))
 
         # Optimize based on size
         if len(data) < 256 * 1024 * 1024:  # < 256 MB
@@ -736,7 +743,7 @@ class AzureBlobStorageClient(StorageClient):
 
     @override
     def download_object(self, filename: str, destination: str | BinaryIO | None = None) -> bytes | None:
-        blob_client = self._container_client.get_blob_client(filename)
+        blob_client = self._container_client.get_blob_client(self._normalize_path(filename))
         if destination is None:
             downloader = blob_client.download_blob()
             return downloader.readall()
@@ -791,6 +798,8 @@ class AzureBlobStorageClient(StorageClient):
         else:
             assert_never(mode)
 
+        filename = self._normalize_path(filename)
+
         start_time = datetime.now(timezone.utc) - timedelta(minutes=10)
         try:
             user_delegation_key: UserDelegationKey = self._blob_service_client.get_user_delegation_key(
@@ -806,7 +815,7 @@ class AzureBlobStorageClient(StorageClient):
 
         sas_token = generate_blob_sas(
             account_name=self._account_name,
-            container_name=self.bucket,
+            container_name=self._container_name,
             blob_name=filename,
             user_delegation_key=user_delegation_key,
             permission=permissions,
@@ -819,6 +828,7 @@ class AzureBlobStorageClient(StorageClient):
 
     def list_files(self, prefix: str, delimiter: Optional[str] = None) -> Iterable[str]:
         try:
+            prefix = self._normalize_path(prefix)
             if delimiter is None:
                 # Flat listing
                 blob_list = self._container_client.list_blobs(name_starts_with=prefix)
@@ -841,12 +851,12 @@ class AzureBlobStorageClient(StorageClient):
             yield filename
 
     def copy(self, source_filename: str, dest_filename: str) -> None:
-        source_blob_url = self.get_https_uri(source_filename)
-        dest_blob_client = self._container_client.get_blob_client(dest_filename)
+        source_blob_url = self.get_https_uri(self._normalize_path(source_filename))
+        dest_blob_client = self._container_client.get_blob_client(self._normalize_path(dest_filename))
         dest_blob_client.start_copy_from_url(source_blob_url)
 
     def get_file_size(self, filename: str) -> int:
-        blob_client = self._container_client.get_blob_client(filename)
+        blob_client = self._container_client.get_blob_client(self._normalize_path(filename))
         properties = blob_client.get_blob_properties()
         size = properties.size
         assert size is not None
